@@ -39,9 +39,8 @@ if sys.version_info[0] >= 3:
     long = int
 
 # Recommended minimum versions
-from distutils.version import StrictVersion
-minimum_numpy_version = StrictVersion('1.7.0')
-
+from distutils.version import LooseVersion
+minimum_numpy_version = LooseVersion('1.7.0')
 
 class test_numexpr(TestCase):
     """Testing with 1 thread"""
@@ -308,13 +307,37 @@ class test_numexpr(TestCase):
         res = evaluate('where(a, b, c)')
         assert_array_equal(res, c)
 
-    # Regression test for issue #310
+    
     def test_refcount(self):
+        # Regression test for issue #310
         a = array([1])
         assert sys.getrefcount(a) == 2
         evaluate('1')
         assert sys.getrefcount(a) == 2
 
+    def test_locals_clears_globals(self):
+        # Check for issue #313, whereby clearing f_locals also clear f_globals
+        # if in the top-frame. This cannot be done inside `unittest` as it is always 
+        # executing code in a child frame.
+        import subprocess
+        script = r';'.join([
+                r"import numexpr as ne",
+                r"a=10",
+                r"ne.evaluate('1')",
+                r"a += 1",
+                r"ne.evaluate('2', local_dict={})",
+                r"a += 1",
+                r"ne.evaluate('3', global_dict={})",
+                r"a += 1",
+                r"ne.evaluate('4', local_dict={}, global_dict={})",
+                r"a += 1",
+            ])
+        # Raises CalledProcessError on a non-normal exit
+        check = subprocess.check_call('{0} -c "{1}"'.format(sys.executable, script), shell=True)
+        # Ideally this test should also be done against ipython but it's not 
+        # a requirement.
+
+
 
 class test_numexpr2(test_numexpr):
     """Testing with 2 threads"""
@@ -1017,7 +1040,7 @@ def print_versions():
     from numexpr.cpuinfo import cpu
     import platform
 
-    np_version = StrictVersion(np.__version__)
+    np_version = LooseVersion(np.__version__)
 
     if minimum_numpy_version < np_version:
         print('*Warning*: NumPy version is lower than recommended: %s < %s' % (np_version, minimum_numpy_version))
